function demo
% A simple demo that sets up a tree, puts local evidence at each node, then
% finds the posterior marginal over the nsoiy-or tree.
%
% David Duvenaud
% March 2011

% Set up tree structure.
parent_ix = [ 0 1 1 2 2 3 3 4 4 5 5 6 6 7 7];
num_nodes = length( parent_ix );
qr_nor = 0.01;    % Noisy-or link failure rate.

% Set local evidence.
local_evidence = ones( num_nodes, 1 ) .* 0.5;
% Add strong evidence at one of the leaf nodes.
local_evidence( end ) = 0.99; 

subplot(1,2,1);
draw_tree( parent_ix, local_evidence .* 10 ); 
title('Local Evidence')

% Evaluate the posterior marginals on the noisy-or tree.
marginals = noisy_or_tree_marginals( parent_ix, local_evidence, qr_nor );

subplot(1,2,2);
draw_tree( parent_ix, marginals .* 10 );
title('Posterior Marginals')
set(gcf, 'Color', [1 1 1 ] );
set(gcf, 'Position', [100 100 800 450 ] );

% Evaluate the likelihood of some data.
data = ones(size(marginals))'
log_likelihood = noisy_or_tree_likelihood( parent_ix, local_evidence, qr_nor, data )


